@@ -443,6 +443,15 @@ function isEllipseEntity(obj) {
     return isOfType(obj, REllipseEntity) || isOfType(obj, REllipseEntityPointer);
 }
 
+/**
+ * Checks if the given object is an ellipse entity and represents an ellipse arc (not a full ellipse).
+ *
+ * \return true if the given object is an ellipse arc entity (REllipseEntity).
+ */
+function isEllipseArcEntity(obj) {
+    return (isOfType(obj, REllipseEntity) || isOfType(obj, REllipseEntityPointer)) && !obj.isFullEllipse();
+}
+
 /**
  * Checks if the given object is an ellipse entity and represents a full ellipse.
  *
@@ -525,6 +534,18 @@ function isClosedPolylineEntity(obj, tolerance) {
     }
 }
 
+/**
+ * \return true if the given object is a geometrically open polyline entity.
+ */
+function isOpenPolylineEntity(obj, tolerance) {
+    if (isNull(tolerance)) {
+        return isPolylineEntity(obj) && !obj.isGeometricallyClosed();
+    }
+    else {
+        return isPolylineEntity(obj) && !obj.isGeometricallyClosed(tolerance);
+    }
+}
+
 /**
  * Checks if the given object is a solid entity.
  *
@@ -868,6 +889,8 @@ function entityTypeToClass(type) {
         return "RLinetype";
     case RS.ObjectView:
         return "RView";
+    case RS.ObjectDimStyle:
+        return "RDimStyle";
 
     case RS.EntityAll:
         return "REntity";
@@ -969,6 +992,8 @@ function entityTypeToString(type, plural) {
         return plural ? qsTr("Linetypes") : qsTr("Linetype");
     case RS.ObjectView:
         return plural ? qsTr("Views") : qsTr("View");
+    case RS.ObjectDimStyle:
+        return plural ? qsTr("Dimension Styles") : qsTr("Dimension Style");
 
     case RS.EntityAll:
         return plural ? qsTr("Entities") : qsTr("Entity");
@@ -1505,6 +1530,23 @@ Array.prototype.containsIgnoreCase = function(obj) {
     return this.contains(obj, function(a,b) { return a.toUpperCase()===b.toUpperCase(); });
 };
 
+/**
+ * \return True if this array contains all items of the given array.
+ */
+Array.prototype.containsAll = function(obj) {
+    if (obj.length>this.length) {
+        return false;
+    }
+
+    for (var i=0; i<obj.length; i++) {
+        if (this.indexOf(obj[i])<0) {
+            return false;
+        }
+    }
+
+    return true;
+};
+
 /**
  * \return Array with all elements of this array that are not also
  * in the given array (subtract).
@@ -1675,6 +1717,22 @@ Array.prototype.filter = function(func, thisArg) {
 //    });
 //};
 
+Array.union = function(x, y) {
+    var i;
+    var obj = {};
+    for (i=x.length-1; i>=0; --i) {
+        obj[x[i]] = x[i];
+    }
+    for (i=y.length-1; i>=0; --i) {
+        obj[y[i]] = y[i];
+    }
+    var res = []
+    for (var k in obj) {
+        res.push(obj[k]);
+    }
+    return res;
+};
+
 /* Finds the intersection of two sorted arrays.
  *
  * \param a first array, must already be sorted
@@ -2816,6 +2874,33 @@ function qsTranslate2(context, sourceText, disambiguation, n) {
     return qsTranslate(context, sourceText, disambiguation, n);
 }
 
+function makeQDirFilters() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(QDir.Filters);
+    return makeFlags.apply(null, argumentsNew);
+}
+
+function makeQDirSortFlags() {
+    var argumentsNew = [].slice.call(arguments, 0);
+    argumentsNew.unshift(QDir.SortFlags);
+    return makeFlags.apply(this, argumentsNew);
+}
+
+function makeFlags() {
+    if (RSettings.isQt(6)) {
+        var ret = 0;
+        for (var i=1; i<arguments.length; i++) {
+            ret |= arguments[i];
+        }
+        return ret;
+    }
+    else {
+        var argumentsNew = [].slice.call(arguments, 0);
+        var flgs = argumentsNew.shift();
+        return flgs.apply(this, argumentsNew);
+    }
+}
+
 // fix QPlainTextEdit API for Qt 5:
 if (!isFunction(QPlainTextEdit.prototype.toPlainText)) {
     QPlainTextEdit.prototype.toPlainText = function() {
